import  {
  select, 
  csv, 
  scaleLinear, 
  scaleBand, 
  max, 
  axisLeft, 
  axisBottom,
  format
} from 'd3';
const svg = select("svg");
const width = +svg.attr("width"),
      height = +svg.attr("height");

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 80, left: 200, bottom: 65, right: 40}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.2);
  const xAxisTickFormat = number => 
  	format('0.3s')(number)
  		.replace('G', 'B');
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight + 8)
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left}, ${margin.top})`)
  const yAxisG = g.append("g").call(axisLeft(yScale))
	yAxisG.selectAll(".domain, .tick line")
  		.remove();
  	
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  xAxisG.selectAll(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('y', 55)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text("Population");
  
  g.selectAll("rect")
  	.data(data)
  	.enter().append("rect")
  	.attr("y", d => yScale(yValue(d)))
  	.attr("width", d => xScale(xValue(d)))
  	.attr("height", yScale.bandwidth());
  
  svg.append("text")
  	.attr("y", 50)
  	.attr("x", width / 2)
  	.attr("text-anchor", "middle")
  	.text("Top 10 Most Populous Countries")
}

csv('data.csv')
	.then(
  data => {
    data.forEach(d => d.population = +d.population)
    render(data)
  })